@@ -34,7 +34,6 @@
 #include "theme.h"
 #include "prefs.h"
 #include "gfx.h"
-#include "games-gridframe.h"
 
 #define SPEED_MOVE     25
 #define SPEED_DROP     20
@@ -489,7 +488,7 @@ prompt_player (void)
   const gchar *who = NULL;
   gchar *str = NULL;
 
-  g_simple_action_set_enabled (G_SIMPLE_ACTION (hint_action), (human || gameover));
+  g_simple_action_set_enabled (G_SIMPLE_ACTION (hint_action), (human && !gameover));
 
   switch (players) {
   case 0:
@@ -532,10 +531,10 @@ prompt_player (void)
 
     if (gameover) {
 	if (player == PLAYER1)
-	  who = _(theme_get_player_win (PLAYER1));
+	  who = theme_get_player_win (PLAYER1);
 	else
-	  who = _(theme_get_player_win (PLAYER2));
-	str = g_strdup_printf (_("%s"), who);
+	  who = theme_get_player_win (PLAYER2);
+	str = g_strdup_printf ("%s", _(who));
       }
     else if (player_active) {
       set_status_message (_("Your Turn"));
@@ -543,10 +542,10 @@ prompt_player (void)
 
     } else {
 	if (player == PLAYER1)
-	  who = _(theme_get_player_turn (PLAYER1));
+	  who = theme_get_player_turn (PLAYER1);
 	else
-	  who = _(theme_get_player_turn (PLAYER2));
-        str = g_strdup_printf (_("%s"), who);
+	  who = theme_get_player_turn (PLAYER2);
+        str = g_strdup_printf ("%s", _(who));
     }
 
     set_status_message (str);
@@ -1162,7 +1161,6 @@ static gboolean
 create_app (void)
 {
   GtkWidget *frame;
-  GtkWidget *gridframe;
   GtkWidget *hbox, *vbox;
   GtkWidget *image;
   GtkWidget *new_game_button;
@@ -1250,7 +1248,7 @@ create_app (void)
   gtk_button_set_label (GTK_BUTTON (hint_button), _("_Hint"));
   gtk_button_set_use_underline (GTK_BUTTON (hint_button), TRUE);
   gtk_widget_set_valign (hint_button, GTK_ALIGN_CENTER);
-  gtk_widget_set_halign (hint_button, GTK_ALIGN_CENTER);
+  gtk_widget_set_halign (hint_button, GTK_ALIGN_FILL);
   gtk_widget_set_size_request (hint_button, 120, 60);
   gtk_actionable_set_action_name (GTK_ACTIONABLE (hint_button), "app.hint");
   gtk_widget_set_tooltip_text (hint_button, _("Receive a hint for your next move"));
@@ -1260,7 +1258,7 @@ create_app (void)
   gtk_button_set_label (GTK_BUTTON (new_game_button), _("_Start Over"));
   gtk_button_set_use_underline (GTK_BUTTON (new_game_button), TRUE);
   gtk_widget_set_valign (new_game_button, GTK_ALIGN_CENTER);
-  gtk_widget_set_halign (new_game_button, GTK_ALIGN_CENTER);
+  gtk_widget_set_halign (new_game_button, GTK_ALIGN_FILL);
   gtk_widget_set_size_request (new_game_button, 120, 60);
   gtk_actionable_set_action_name (GTK_ACTIONABLE (new_game_button), "app.new-game");
   gtk_widget_set_tooltip_text (new_game_button, _("Start a new game"));
